@@ -10,7 +10,7 @@ import platform
 from datetime import datetime
 
 
-class cpu:
+class CPU:
     
     info = cpuinfo.get_cpu_info()
     
@@ -21,36 +21,36 @@ class cpu:
     
     @staticmethod
     def architecture():
-        return cpu.info['arch']
+        return CPU.info['arch']
     
     
     @staticmethod
     def name():
-        return cpu.info['brand_raw']
+        return CPU.info['brand_raw']
     
     @staticmethod
     def percent():
         return psutil.cpu_percent(0.2) 
     
     
-class ram:
+class Ram:
     
     mem = psutil.virtual_memory()
     
     @staticmethod
     def total_mem(acc):
-        return round(ram.mem.total/1000000000, acc)
+        return round(Ram.mem.total/1000000000, acc)
     
     @staticmethod
     def used_mem(acc):
-        return round(ram.mem.used/1000000000, acc)
+        return round(Ram.mem.used/1000000000, acc)
     
     @staticmethod
     def free_mem(acc):
-        return round(ram.mem.available/1000000000, acc)
+        return round(Ram.mem.available/1000000000, acc)
     
   
-class disk:
+class Disk:
     
     @staticmethod
     def list_disks(every = False):
@@ -74,7 +74,7 @@ class disk:
     @staticmethod
     def total_r_and_w():
         disk_io = psutil.disk_io_counters()
-        return {'read': disk.get_size(disk_io.read_bytes), 'write': disk.get_size(disk_io.write_bytes)}
+        return {'read': Disk.get_size(disk_io.read_bytes), 'write': Disk.get_size(disk_io.write_bytes)}
     
     @staticmethod
     def space(every=False):
@@ -88,16 +88,16 @@ class disk:
                 # isn't ready
                 continue
             to_return[(partition.device, partition.mountpoint, partition.fstype)] = {
-                'total': disk.get_size(partition_usage.total), 
-                'used': disk.get_size(partition_usage.used),
-                'free': disk.get_size(partition_usage.free),
+                'total': Disk.get_size(partition_usage.total), 
+                'used': Disk.get_size(partition_usage.used),
+                'free': Disk.get_size(partition_usage.free),
                 'usage_percentage': partition_usage.percent
 
             }
         return to_return
 
 
-class network:
+class Network:
     
     @staticmethod
     def get_ip():
@@ -108,14 +108,14 @@ class network:
             s.connect(('10.255.255.255', 1))
             IP = s.getsockname()[0]
         except Exception:
-            IP = '127.0.0.1'
+            IP = None
         finally:
             s.close()
         return IP
   
   
   
-class os:
+class OS:
     
     @staticmethod
     def name():
@@ -164,5 +164,3 @@ class os:
     def battery_info():
         info = (list(psutil.sensors_battery()))
         return {'Percentage': info[0], 'SecondLeft': info[1], 'MinutesLeft': round(info[1]/60), 'HoursLeft': round(info[1]/1440, 2), 'PluggedIn': info[2]}
-    
-    
\ No newline at end of file
